﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Diagnostics;

namespace ROTools.ROWebLogin {

    /// <summary>
    /// 設定用画面
    /// </summary>
    public partial class ConfigForm : Form {

        /// <summary>
        /// 設定内容
        /// </summary>
        public AppConfigData AppConfig {
            set;
            get;
        }


        /// <summary>
        /// 暗号化パスフレーズ
        /// </summary>
        public string CryptoPassPhrase {
            set;
            get;
        }


        private bool formLoaded = false;

        /// <summary>
        /// コンストラクタ
        /// </summary>
        public ConfigForm() {
            InitializeComponent();
        }


        /// <summary>
        /// フォーム初期化処理
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ConfigForm_Load(object sender, EventArgs e) {
            // 設定内容を画面に反映
            cryptoConfigCheckBox.Checked = AppConfig.IsConfigCrypto;
            autoAdminExecCheckBox.Checked = AppConfig.IsAutoAdminExec;
            autoLogoutExecCheckBox.Checked = AppConfig.IsAutoLogoutExec;
            switch(AppConfig.OnPatchClientExecOperate) {
                case "Terminate":
                    onPatchClientExecOperate2RadioButton.Checked = true;
                    break;
                case "Minimize":
                    onPatchClientExecOperate3RadioButton.Checked = true;
                    break;
                default:
                    onPatchClientExecOperate1RadioButton.Checked = true;
                    break;
            }
            switch(AppConfig.OnGameClientTerminateOperate) {
                case "Normalize":
                    onGameClientTerminateOperate2RadioButton.Checked = true;
                    break;
                default:
                    onGameClientTerminateOperate1RadioButton.Checked = true;
                    break;
            }
            if(string.IsNullOrEmpty(AppConfig.ExplicitRagPath)) {
                specifyRagPathText.Text = "";
                specifyRagPathCheckBox.Checked = false;
            } else {
                specifyRagPathText.Text = AppConfig.ExplicitRagPath;
                specifyRagPathCheckBox.Checked = true;
            }
            specifyRagPathCheckBox_CheckedChanged(sender, e);
            formLoaded = true;
        }


        /// <summary>
        /// 閉じるボタン
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void closeButton_Click(object sender, EventArgs e) {
            DialogResult = DialogResult.OK;
        }


        /// <summary>
        /// 暗号化設定
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void cryptoConfigCheckBox_CheckedChanged(object sender, EventArgs e) {
            if(!formLoaded) {
                return;
            }
            AppConfig.IsConfigCrypto = false;
            if(cryptoConfigCheckBox.Checked) {
                using(PassPhraseInputForm form = new PassPhraseInputForm()) {
                    form.Location = this.Location;
                    if(form.ShowDialog() == DialogResult.OK) {
                        CryptoPassPhrase = form.PassPhrase;
                        AppConfig.IsConfigCrypto = true;
                    } else {
                        cryptoConfigCheckBox.Checked = false;
                    }
                }
            }
        }

        /// <summary>
        /// パッチクライアント実行時処理指定
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void onPatchClientExecOperateRadioButton_CheckedChanged(object sender, EventArgs e) {
            RadioButton control = (RadioButton)sender;
            if(control.Checked) {
                if(control == onPatchClientExecOperate1RadioButton) {
                    AppConfig.OnPatchClientExecOperate = "";
                } else if(control == onPatchClientExecOperate2RadioButton) {
                    AppConfig.OnPatchClientExecOperate = "Terminate";
                } else if(control == onPatchClientExecOperate3RadioButton) {
                    AppConfig.OnPatchClientExecOperate = "Minimize";
                }
            }
        }


        /// <summary>
        /// ゲームクライアント終了時処理指定
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void onGameClientTerminateOperateRadioButton_CheckedChanged(object sender, EventArgs e) {
            RadioButton control = (RadioButton)sender;
            if(control.Checked) {
                if(control == onGameClientTerminateOperate1RadioButton) {
                    AppConfig.OnGameClientTerminateOperate = "";
                } else if(control == onGameClientTerminateOperate2RadioButton) {
                    AppConfig.OnGameClientTerminateOperate = "Normalize";
                }
            }
        }

        /// <summary>
        /// セットアップ先指定チェックボックス
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void specifyRagPathCheckBox_CheckedChanged(object sender, EventArgs e) {
            specifyRagPathButton.Enabled = specifyRagPathCheckBox.Checked;
            specifyRagPathText.Enabled = specifyRagPathCheckBox.Checked;
            if(specifyRagPathCheckBox.Checked) {
                if(formLoaded) {
                    specifyRagPathButton_Click(sender, e);
                }
            } else {
                specifyRagPathText.Text = "";
            }
        }

        /// <summary>
        /// セットアップ先指定ボタン
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void specifyRagPathButton_Click(object sender, EventArgs e) {
            // フォルダを開くダイアログを表示
            folderBrowserDialog1.ShowNewFolderButton = false;
            folderBrowserDialog1.Description = @"RagnarokOnlineがセットアップされているフォルダを指定してください";
            if(!string.IsNullOrEmpty(specifyRagPathText.Text)) {
                folderBrowserDialog1.SelectedPath = specifyRagPathText.Text;
            }
            if(folderBrowserDialog1.ShowDialog() == DialogResult.OK) {
                specifyRagPathText.Text = folderBrowserDialog1.SelectedPath;
            }
        }

        /// <summary>
        /// フォームを閉じるとき
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ConfigForm_FormClosing(object sender, FormClosingEventArgs e) {
            // 設定を保存する
            AppConfig.IsAutoAdminExec = autoAdminExecCheckBox.Checked;
            AppConfig.IsAutoLogoutExec = autoLogoutExecCheckBox.Checked;
            AppConfig.ExplicitRagPath = specifyRagPathText.Text;
        }


    }
}
