﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Security.Cryptography;
using System.IO;

namespace ROTools.ROWebLogin {

    public static class CryptoUtil {

        /// <summary>
        /// バイト配列を所定のサイズへ合わせる
        /// </summary>
        /// <param name="bytes"></param>
        /// <param name="newSize"></param>
        /// <returns></returns>
        private static byte[] ResizeBytesArray(byte[] bytes, int newSize) {
            byte[] newBytes = new byte[newSize];
            if(bytes.Length <= newSize) {
                for(int i = 0; i < bytes.Length; i++) {
                    newBytes[i] = bytes[i];
                }
            } else {
                int pos = 0;
                for(int i = 0; i < bytes.Length; i++) {
                    newBytes[pos++] ^= bytes[i];
                    if(pos >= newBytes.Length) {
                        pos = 0;
                    }
                }
            }
            return newBytes;
        }


        /// <summary>
        /// 暗号キーを設定する
        /// </summary>
        /// <param name="provider"></param>
        /// <param name="key"></param>
        public static void SetCipherKey(DESCryptoServiceProvider provider, string key) {
            byte[] keyBytes = Encoding.UTF8.GetBytes(key);
            provider.Key = ResizeBytesArray(keyBytes, provider.Key.Length);
            provider.IV = ResizeBytesArray(keyBytes, provider.IV.Length);
        }


        /// <summary>
        /// DES暗号化処理オブジェクトを生成する
        /// </summary>
        /// <param name="key"></param>
        /// <returns></returns>
        public static DESCryptoServiceProvider CreateProvider(string key) {
            DESCryptoServiceProvider provider = new DESCryptoServiceProvider();
            SetCipherKey(provider, key);
            return provider;
        }

    }

}
